@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 #use warnings;
 
-our $VERSION = '0.5400';
+our $VERSION = '0.5401';
 
 use Carp;
 use Math::BigInt;
@@ -25,8 +25,8 @@ use overload
   fallback => 1;
 
 my %DEF = (
-  CURRENT => { TAGS => ['NORMAL', 'REDUCE', 'SMALL', 'AUTO'], DIGITS => undef, SYSTEM => 1, NAME => 'DEFAULT' },
-  DEFAULT => { TAGS => ['NORMAL', 'REDUCE', 'SMALL', 'AUTO'], DIGITS => undef, READONLY => 1, SYSTEM => 1 },
+  CURRENT => { TAGS => [qw/ NORMAL REDUCE SMALL AUTO /], DIGITS => undef, SYSTEM => 1, NAME => 'DEFAULT' },
+  DEFAULT => { TAGS => [qw/ NORMAL REDUCE SMALL AUTO /], DIGITS => undef, READONLY => 1, SYSTEM => 1 },
   BLANK   => { TAGS => ['', '', ''], DIGITS => '', READONLY => 1, SYSTEM => 1 },
 );
 
@@ -642,8 +642,8 @@ sub _reduce {
 sub _simplify_sign {
   my @frac = @_;
   my $sign = 1;
-  $sign = ($frac[0] / abs($frac[0])) * ($frac[1] / abs($frac[1])) if $frac[0];
-  @frac = ($sign * abs($frac[0]), abs($frac[1]));
+  $sign = ($frac[0] / CORE::abs($frac[0])) * ($frac[1] / CORE::abs($frac[1])) if $frac[0];
+  @frac = ($sign * CORE::abs($frac[0]), CORE::abs($frac[1]));
   return @frac;
 }
 
@@ -697,7 +697,7 @@ sub _tags_preserve {
 }
 
 sub _gcd {
-  my ($x, $y) = (abs($_[0]), abs($_[1]));
+  my ($x, $y) = (CORE::abs($_[0]), CORE::abs($_[1]));
   if (ref($x)) {
     $x = Math::BigInt->new($x->bgcd($y));
   }
@@ -863,7 +863,7 @@ Math::FractionManip - Manipulate fractions
 
 =head1 VERSION
 
-version 0.5400
+version 0.5401
 
 =head1 SYNOPSIS
 
